/*****************************************************************************
 * libsangoma.c	AFT T1/E1: HDLC API Code Library
 *
 * Author(s):	Anthony Minessale II <anthmct@yahoo.com>
 *              Nenad Corbic <ncorbic@sangoma.com>
 *
 * Copyright:	(c) 2005 Anthony Minessale II
 *
 *		This program is free software; you can redistribute it and/or
 *		modify it under the terms of the GNU General Public License
 *		as published by the Free Software Foundation; either version
 *		2 of the License, or (at your option) any later version.
 * ============================================================================
 */

#ifndef _LIBSNAGOMA_H
#define _LIBSNAGOMA_H

#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/time.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <linux/if_wanpipe.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <linux/if.h>
#include <linux/wanpipe_defines.h>
#include <linux/wanpipe_cfg.h>
#include <linux/wanpipe.h>
#include <linux/sdla_aft_te1.h>

#define WANPIPE_TDM_API 1

#ifdef WANPIPE_TDM_API
# include <linux/wanpipe_tdm_api.h>
#endif

#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <stdlib.h>
#include <unistd.h>
#include <signal.h>
#include <sys/signal.h>
#include <sys/select.h>
#include <sys/wait.h>
#include <sys/resource.h>
#include <sys/time.h>

typedef api_rx_hdr_t sangoma_api_hdr_t;

/* Socket Create/Bind functions
 * create_socket: Creates a socket on specific span and first available chan 
 * create_socket_by_name: Creates a socket on a specific chan name
 * create_socket_intr: Creates a socket on specific chan based on span/chan numbers 
 */
int sangoma_create_socket(int span); 
int sangoma_create_socket_by_name(char *device, char *card);
int sangoma_create_socket_intr(int span, int intr);

/* Socket Rx/Tx functions 
 * sendmsg: tx header + data from separate buffers 
 * recvmsg: rx header + data to separate buffers
 * wrte:    tx header + data from single buffer   
 * read:    rx header + data to single buffer
 */
int sangoma_sendmsg_socket(int sock, void *hdrbuf, int hdrlen, void *databuf, int datalen, int flag);
int sangoma_readmsg_socket(int sock, void *hdrbuf, int hdrlen, void *databuf, int datalen, int flag);
int sangoma_write_socket(int sock, void *data, int len);
int sangoma_read_socket(int sock, void *data, int len);

/* Decodec Span/Chan from interface name */
int sangoma_interface_toi(char *interface, int *span, int *chan);

#ifdef WANPIPE_TDM_API

/* Get Full TDM API configuration per chan */
int sangoma_get_full_cfg(int sock, wanpipe_tdm_api_t *tdm_api);

/* Get/Set TDM Codec per chan */
int sangoma_tdm_set_codec(int sock, wanpipe_tdm_api_t *tdm_api, int codec);
int sangoma_tdm_get_codec(int sock, wanpipe_tdm_api_t *tdm_api);

/* Get/Set HW Tx/Rx Period in milliseconds */
int sangoma_tdm_set_hw_period(int sock, wanpipe_tdm_api_t *tdm_api, int period);
int sangoma_tdm_get_hw_period(int sock, wanpipe_tdm_api_t *tdm_api);

/* Get user MTU/MRU values in bytes */
int sangoma_tdm_get_usr_mtu_mru(int sock, wanpipe_tdm_api_t *tdm_api);

/* Not supported yet */
int sangoma_tdm_set_power_level(int sock, wanpipe_tdm_api_t *tdm_api, int power);
int sangoma_tdm_get_power_level(int sock, wanpipe_tdm_api_t *tdm_api);

/* Flush buffers from current channel */
int sangoma_tdm_flush_bufs(int sock, wanpipe_tdm_api_t *tdm_api);

#endif 	/* WANPIPE_TDM_API */

#endif
